@@ -2,10 +2,10 @@
 pset = "Allgemeine_Eigenschaften:";
 ident_attrib = "bauteilKlassifikation";
 
-status = desiteAPI.getPropertyValue(id, "Check_State", "xs:string");
+stat = desiteAPI.getPropertyValue(id, "Check_State", "xs:string");
 objekttyp = desiteAPI.getPropertyValue(id, pset + ident_attrib, "xs:string");
 
-if (status == "Ungeprüft") {
+if (stat == "Ungeprüft") {
     desiteResult.setCheckState('failed');
 
     check_status = "Failed"
